@@ -2,7 +2,7 @@
 
 #
 #    BEDOPS
-#    Copyright (C) 2011-2017 Shane Neph, Scott Kuehn and Alex Reynolds
+#    Copyright (C) 2011-2018 Shane Neph, Scott Kuehn and Alex Reynolds
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -32,11 +32,20 @@ import logging
 name = "starch-diff"
 citation = "  citation: http://bioinformatics.oxfordjournals.org/content/28/14/1919.abstract"
 authors = "  authors:  Alex Reynolds and Shane Neph"
-version = "  version:  2.4.26"
+version = "  version:  2.4.35"
 usage = "  $ starch-diff [ --chr <chr> ] starch-file-1 starch-file-2 [ starch-file-3 ... ]"
 help = """
   The 'starch-diff' utility compares the signatures of two or more specified 
   Starch v2.2+ archives for all chromosomes, or for a specified chromosome.
+  
+  The typical output of 'starch-diff' is a message indicating that the 
+  archives' chromosome(s) are identical or dissimilar, written to the standard
+  error stream.
+  
+  In addition, if all chromosomes are identical, 'starch-diff' exits with a 
+  zero status code. Likewise, if any chromosomes are dissimilar, 'starch-diff'
+  exits with a non-zero status code. This facilitates testing in a scripting
+  environment.
 """
 
 default_chromosome = "all"
