@@ -6,7 +6,7 @@
 
 //
 //    BEDOPS
-//    Copyright (C) 2011-2017 Shane Neph, Scott Kuehn and Alex Reynolds
+//    Copyright (C) 2011-2018 Shane Neph, Scott Kuehn and Alex Reynolds
 //
 //    This program is free software; you can redistribute it and/or modify
 //    it under the terms of the GNU General Public License as published by
@@ -57,6 +57,9 @@ namespace starch {
 #define STARCHCAT_RETRANSFORM_BUFFER_SIZE 1024*1024
 #define STARCHCAT_FIELD_BUFFER_MAX_LENGTH 16
 
+#define GCC_COMPILER (defined(__GNUC__) && !defined(__clang__))
+#define CLANG_COMPILER defined(__clang__)
+
 /*
     This is simply a struct containing a starch file's
     metadata, pathname and other data useful for our 
@@ -88,7 +91,7 @@ typedef struct transformState {
     SignedCoordType          t_lastEnd;
     char                     t_firstInputToken[UNSTARCH_FIRST_TOKEN_MAX_LENGTH + 1];
     char                     t_secondInputToken[UNSTARCH_SECOND_TOKEN_MAX_LENGTH + 1];
-    char                     t_currentChromosome[TOKEN_CHR_MAX_LENGTH + 1];
+    char                     t_currentChromosome[TOKEN_CHR_MAX_LENGTH];
     size_t                   t_currentChromosomeLength;
     SignedCoordType          t_currentStart;
     SignedCoordType          t_currentStop;
@@ -98,7 +101,7 @@ typedef struct transformState {
     SignedCoordType          t_lcDiff;    
     size_t                   t_nExtractionBuffer;
     size_t                   t_nExtractionBufferPos;
-    char                     r_chromosome[TOKEN_CHR_MAX_LENGTH + 1];
+    char                     r_chromosome[TOKEN_CHR_MAX_LENGTH];
     char                     r_remainder[UNSTARCH_SECOND_TOKEN_MAX_LENGTH + 1];
     SignedCoordType          r_start;
     SignedCoordType          r_stop;
