@@ -4,7 +4,7 @@
 */
 //
 //    BEDOPS
-//    Copyright (C) 2011-2017 Shane Neph, Scott Kuehn and Alex Reynolds
+//    Copyright (C) 2011-2018 Shane Neph, Scott Kuehn and Alex Reynolds
 //
 //    This program is free software; you can redistribute it and/or modify
 //    it under the terms of the GNU General Public License as published by
@@ -21,8 +21,8 @@
 //    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
 
-#ifndef BED_HPP
-#define BED_HPP
+#ifndef BED_NONEW_HPP
+#define BED_NONEW_HPP
 
 #include <cstddef>
 #include <cstdio>
@@ -50,12 +50,9 @@
 
 namespace Bed {
 
-  // For Bed6<> items, but much easier to use if directly in Bed namespace
-  enum Strand { PLUS = '+', MINUS = '-' };
-
-  const CoordType MAXCHROMSIZE = TOKEN_CHR_MAX_LENGTH;
-  const CoordType MAXIDSIZE = TOKEN_ID_MAX_LENGTH;
-  const CoordType MAXRESTSIZE = TOKEN_REST_MAX_LENGTH;
+  constexpr CoordType MAXCHROMSIZE = TOKEN_CHR_MAX_LENGTH;
+  constexpr CoordType MAXIDSIZE = TOKEN_ID_MAX_LENGTH;
+  constexpr CoordType MAXRESTSIZE = TOKEN_REST_MAX_LENGTH;
 
 
   /*****************************************/
@@ -63,48 +60,26 @@ namespace Bed {
   /*****************************************/
 
   // ChromInfo non-specialized declaration
-  template <bool IsNonStatic>
+  template <bool isNonStatic>
   struct ChromInfo {
+    static constexpr bool IsNonStatic = isNonStatic;
 
-    ChromInfo() : chrom_(new char[1]) { chrom_[0] = '\0'; }
-    ChromInfo(const ChromInfo& c)
-        : chrom_(new char[(c.chrom_ != NULL) ? (std::strlen(c.chrom_) + 1) : 1])
-      { *chrom_ = '\0'; if ( c.chrom_ != NULL ) std::strcpy(chrom_, c.chrom_); }
-    explicit ChromInfo(char const* c)
-        : chrom_(new char[(c != NULL) ? (std::strlen(c)+1) : 1])
-      { *chrom_ = '\0'; if ( c != NULL ) std::strcpy(chrom_, c); }
+    ChromInfo() { chrom_[0] = '\0'; }
+    ChromInfo(const ChromInfo& c) { std::strcpy(chrom_, c.chrom_); }
+    explicit ChromInfo(char const* c)  { std::strcpy(chrom_, c); }
 
     // Properties
-    char const* chrom() const { return chrom_; }
-    void chrom(char const* chrom) {
-      if ( chrom_ )
-        delete [] chrom_;
-      if ( chrom != NULL ) {
-        chrom_ = new char[std::strlen(chrom) + 1];
-        std::strcpy(chrom_, chrom);
-      } else {
-        chrom_ = new char[1];
-        *chrom_ = '\0';
-      }
-    }
+    inline char const* chrom() const { return chrom_; }
+    inline void chrom(char const* chrom) { std::strcpy(chrom_, chrom); }
 
     // Operators
     ChromInfo& operator=(const ChromInfo& c) {
-      if ( chrom_ )
-        delete [] chrom_;
-      chrom_ = new char[(c.chrom_ != NULL) ? (std::strlen(c.chrom_) + 1) : 1];
-      *chrom_ = '\0'; if ( c.chrom_ != NULL ) std::strcpy(chrom_, c.chrom_);
+      std::strcpy(chrom_, c.chrom_);
       return *this;
     }
 
-    ~ChromInfo() { 
-      if ( chrom_ )
-        delete [] chrom_;
-      chrom_ = NULL;
-    }
-
   protected:
-    char* chrom_;
+    char chrom_[MAXCHROMSIZE+1];
   };
 
 
@@ -151,8 +126,8 @@ namespace Bed {
       { this->readline(inS); }
 
     // Properties
-    CoordType length() const { return end_ - start_; }
-    CoordType median() const { return start_ + ((end_ - start_) / 2); }
+    inline CoordType length() const { return end_ - start_; }
+    inline CoordType median() const { return start_ + ((end_ - start_) / 2); }
     inline CoordType distance(const BasicCoords& a) const {
       if ( 0 == std::strcmp(chrom_, a.chrom_) )
         return start_ - a.start_;
@@ -163,10 +138,10 @@ namespace Bed {
         return end_ - a.start_;
       return std::numeric_limits<CoordType>::max();
     }
-    void start(CoordType start) { start_ = start; }
-    CoordType start() const { return start_; }
-    void end(CoordType end) { end_ = end; }
-    CoordType end() const { return end_; }
+    inline void start(CoordType start) { start_ = start; }
+    inline CoordType start() const { return start_; }
+    inline void end(CoordType end) { end_ = end; }
+    inline CoordType end() const { return end_; }
 
     // Comparison utilities
     inline CoordType overlap(const BasicCoords& a) const {
@@ -230,27 +205,27 @@ namespace Bed {
       static char const* format = heapFormat.c_str();
       std::printf(format, chrom_, start_, end_);
     }
+    inline std::string printstr() const {
+      static const std::string tab = "\t";
+      return std::string(chrom_) + tab + std::to_string(start_) + tab + std::to_string(end_);
+    }
     inline int readline(const std::string& inputLine) {
-      static char chrBuf[MAXCHROMSIZE + 1];
-      chrBuf[0] = '\0';
       static const std::string lclStatic = inFormatter();
       static char const* format = lclStatic.c_str();
+      *chrom_ = '\0';
       int numScan = std::sscanf(inputLine.c_str(),
-                                format, chrBuf,
+                                format, chrom_,
                                 &start_, &end_);
-      this->chrom(chrBuf);
       return numScan;
     }
     inline int readline(FILE* inputFile) {
-      static char chrBuf[MAXCHROMSIZE + 1];
-      chrBuf[0] = '\0';
       static std::string lclstatic = inFormatter();
       static char const* format = lclstatic.c_str();
+      *chrom_ = '\0';
       int numScan = std::fscanf(inputFile,
-                                format, chrBuf, 
+                                format, chrom_,
                                 &start_, &end_);
       std::fgetc(inputFile); // chomp newline
-      this->chrom(chrBuf);
       return numScan;
     }
 
@@ -278,37 +253,22 @@ namespace Bed {
   struct BasicCoords
     : public BasicCoords<IsNonStaticChrom, false> {
 
-    BasicCoords() : BaseClass(), rest_(new char[1]) { *rest_ = '\0'; }
-    BasicCoords(char const* chrom, CoordType start, CoordType end, char const* rest = NULL)
-      : BaseClass(chrom, start, end), rest_(new char[(rest != NULL) ? (std::strlen(rest)+1) : 1]) {
-      *rest_ = '\0';
-      if ( rest && std::strcmp(rest, "") != 0 ) {
-        if ( rest[0] != '\t' )
-          rest_[0] = '\t';
-        std::strcat(rest_, rest);
-      }
-    }
+    BasicCoords() : BaseClass() { fullrest_[0] = '\0'; }
     BasicCoords(const BasicCoords& c)
-      : BaseClass(c), rest_(new char[(c.rest_ != NULL) ? (std::strlen(c.rest_) + 1) : 1])
-      { *rest_ = '\0'; if ( c.rest_ != NULL ) std::strcpy(rest_, c.rest_); }
-    explicit BasicCoords(FILE* inF) : BaseClass(), rest_(0)
+      : BaseClass(c)
+      { std::strcpy(fullrest_, c.fullrest_); }
+    explicit BasicCoords(FILE* inF) : BaseClass()
       { this->readline(inF); }
-    explicit BasicCoords(const std::string& inS) : BaseClass(), rest_(0)
+    explicit BasicCoords(const std::string& inS) : BaseClass()
       { this->readline(inS); }
 
     // Properties
-    char const* rest() const { return rest_; }
-    char const* full_rest() const { return rest(); }
+    inline char const* full_rest() const { return fullrest_; }
 
     // Operators
     BasicCoords& operator=(const BasicCoords& c) {
       BaseClass::operator=(c);
-      if ( rest_ )
-        delete [] rest_;
-      rest_ = new char[(c.rest_ != NULL) ? (std::strlen(c.rest_) + 1) : 1];
-      *rest_ = '\0';
-      if ( c.rest_ != NULL )
-        std::strcpy(rest_, c.rest_);
+      std::strcpy(fullrest_, c.fullrest_);
       return *this;
     }
 
@@ -316,54 +276,40 @@ namespace Bed {
     inline void print() const {
       static const std::string lclStatic = outFormatter();
       static char const* format = lclStatic.c_str();
-      std::printf(format, chrom_, start_, end_, rest_);
+      std::printf(format, chrom_, start_, end_, fullrest_);
     }
     inline void println() const {
       static const std::string heapFormat = (outFormatter() + "\n");
       static char const* format = heapFormat.c_str();
-      std::printf(format, chrom_, start_, end_, rest_);
+      std::printf(format, chrom_, start_, end_, fullrest_);
+    }
+    inline std::string printstr() const {
+      static const std::string tab = "\t";
+      return std::string(chrom_) + tab + std::to_string(start_) + tab + std::to_string(end_)
+               + std::string(fullrest_); /* fullrest_ has a starting tab if applicable */
     }
     inline int readline(const std::string& inputLine) {
-      static char chrBuf[MAXCHROMSIZE + 1];
-      chrBuf[0] = '\0';
-      static char restBuf[MAXRESTSIZE + 1];
-      restBuf[0] = '\0';
       static const std::string lclStatic = inFormatter();
       static char const* format = lclStatic.c_str();
+      chrom_[0] = '\0';
+      fullrest_[0] = '\0';
       int numScan = std::sscanf(inputLine.c_str(), 
-                                format, chrBuf, &start_,
-                                &end_, restBuf);
-      this->chrom(chrBuf);
-      if ( rest_ )
-        delete [] rest_;
-      rest_ = new char[std::strlen(restBuf) + 1];
-      std::strcpy(rest_, restBuf);
+                                format, chrom_, &start_,
+                                &end_, fullrest_);
       return numScan;
     }
     inline int readline(FILE* inputFile) {
-      static char chrBuf[MAXCHROMSIZE + 1];
-      chrBuf[0] = '\0';
-      static char restBuf[MAXRESTSIZE + 1];
-      restBuf[0] = '\0';
       static const std::string lclStatic = inFormatter();
       static char const* format = lclStatic.c_str();
+      chrom_[0] = '\0';
+      fullrest_[0] = '\0';
       int numScan = std::fscanf(inputFile, format,
-                                chrBuf, &start_,
-                                &end_, restBuf);
+                                chrom_, &start_,
+                                &end_, fullrest_);
       std::fgetc(inputFile); // chomp newline
-      this->chrom(chrBuf);
-      if ( rest_ )
-        delete [] rest_;
-      rest_ = new char[std::strlen(restBuf) + 1];
-      std::strcpy(rest_, restBuf);
       return numScan;
     }
 
-    ~BasicCoords() {
-      if ( rest_ )
-        delete [] rest_;
-    }
-
     static const bool UseRest = true;
 
   protected:
@@ -371,7 +317,7 @@ namespace Bed {
     using BaseClass::chrom_;
     using BaseClass::start_;
     using BaseClass::end_;
-    char* rest_;
+    char fullrest_[MAXRESTSIZE + 1];
 
     static std::string outFormatter() {
       return(std::string("%s\t%" PRIu64 "\t%" PRIu64 "%s"));
@@ -381,7 +327,7 @@ namespace Bed {
       return(std::string("%s\t%" SCNu64 "\t%" SCNu64 "%[^\n]s\n"));
     }
   };
-  
+
 
   /*****************************************/
   /* Bed4 Classes                         */
@@ -396,52 +342,35 @@ namespace Bed {
   struct Bed4<BasicCoords<IsNonStaticChrom, B3HasRest>, false> 
     : public BasicCoords<IsNonStaticChrom, false> {
 
-    Bed4() : BaseClass(), id_(new char[1]) { *id_ = '\0'; }
+    Bed4() : BaseClass() { *id_ = '\0'; }
     Bed4(char const* chrom, CoordType start, CoordType end, char const* id)
-      : BaseClass(chrom, start, end), id_(new char[(id != NULL) ? (std::strlen(id)+1) : 1])
-      { *id_ = '\0'; if ( id != NULL ) std::strcpy(id_, id); }
+      : BaseClass(chrom, start, end)
+      { *id_ = '\0'; if ( id != nullptr ) std::strcpy(id_, id); }
     Bed4(const Bed4& c)
-      : BaseClass(c), id_(new char[(c.id_ != NULL) ? (std::strlen(c.id_) + 1) : 1])
-      { *id_ = '\0'; if ( c.id_ != NULL ) std::strcpy(id_, c.id_); }
-    explicit Bed4(FILE* inF) : BaseClass(), id_(0)
+      : BaseClass(c)
+      { *id_ = '\0'; std::strcpy(id_, c.id_); }
+    explicit Bed4(FILE* inF) : BaseClass()
       { this->readline(inF); }
-    explicit Bed4(const std::string& inS) : BaseClass(), id_(0)
+    explicit Bed4(const std::string& inS) : BaseClass()
       { this->readline(inS); }
 
     // IO
     inline int readline(const std::string& inputLine) {
-      static char chrBuf[MAXCHROMSIZE + 1];
-      chrBuf[0] = '\0';
-      static char idBuf[MAXIDSIZE + 1];
-      idBuf[0] = '\0';
-
       static const std::string lclStatic = inFormatter();
       static char const* format = lclStatic.c_str();
-      int numScanned = std::sscanf(inputLine.c_str(), format,
-                                   chrBuf,
-                                   &start_,
-                                   &end_,
-                                   idBuf);
-      this->chrom(chrBuf);
-      this->id(idBuf);
-      return numScanned;
+      *chrom_ = '\0';
+      *id_ = '\0';
+      return std::sscanf(inputLine.c_str(), format,
+                         chrom_, &start_, &end_, id_);
     }
     inline int readline(FILE* inputFile) {
-      static char chrBuf[MAXCHROMSIZE + 1];
-      chrBuf[0] = '\0';
-      static char idBuf[MAXIDSIZE + 1];
-      idBuf[0] = '\0';
-
       static const std::string lclStatic = inFormatter();
       static char const* format = lclStatic.c_str();
+      *chrom_ = '\0';
+      *id_ = '\0';
       int numScanned = std::fscanf(inputFile, format,
-                                   chrBuf,
-                                   &start_,
-                                   &end_, 
-                                   idBuf);
+                                   chrom_, &start_, &end_, id_);
       std::fgetc(inputFile); // read and discard newline
-      this->chrom(chrBuf);
-      this->id(idBuf);
       return numScanned;
     }
     inline void print() const {
@@ -454,32 +383,24 @@ namespace Bed {
       static char const* format = heapFormat.c_str();
       printf(format, chrom_, start_, end_, id_);
     }
+    inline std::string printstr() const {
+
+      static const std::string tab = "\t";
+      return std::string(chrom_) + tab + std::to_string(start_) + tab + std::to_string(end_) + tab
+               + std::string(id_);
+    }
 
     // Properties
-    void id(char const* id) {
-      if ( id_ )
-        delete [] id_;
-      id_ = new char[(id != NULL) ? (std::strlen(id) + 1) : 1];
-      *id_ = '\0'; if ( id != NULL ) std::strcpy(id_, id);
-    }
-    char const* id() const { return id_; }
+    inline void id(char const* id) { *id_ = '\0'; if ( id != nullptr ) std::strcpy(id_, id); }
+    inline char const* id() const { return id_; }
 
     // Operators
     Bed4& operator=(const Bed4& c) {
       BaseClass::operator=(c);
-      if ( id_ )
-        delete [] id_;
-      id_ = new char[(c.id_ != NULL) ? (std::strlen(c.id_) + 1) : 1];
-      *id_ = '\0'; if ( c.id_ != NULL ) std::strcpy(id_, c.id_);
+      std::strcpy(id_, c.id_);
       return *this;
     }
 
-    ~Bed4() {
-      if ( id_ )
-        delete [] id_;
-      id_ = NULL;
-    }
-
     static const int NumFields = 4;
     static const bool UseRest = false;
 
@@ -489,7 +410,7 @@ namespace Bed {
     using BaseClass::start_;
     using BaseClass::end_;
 
-    char* id_;
+    char id_[MAXIDSIZE+1];
 
     static std::string outFormatter() {
       return(BaseClass::outFormatter() + "\t%s");
@@ -505,127 +426,81 @@ namespace Bed {
   struct Bed4 
     : public Bed4<BedType, false> {
 
-    Bed4() : BaseClass(), rest_(new char[1]), fullrest_(new char[1]) { *rest_ = '\0'; *fullrest_ = '\0'; }
+    Bed4() : BaseClass() { *fullrest_ = '\0'; }
     Bed4(const Bed4& c)
-      : BaseClass(c), rest_(new char[(c.rest_ != NULL) ? (std::strlen(c.rest_)+1) : 1]),
-                     fullrest_(new char[(c.fullrest_ != NULL) ? (std::strlen(c.fullrest_)+1) : 1])
-       { *rest_ = '\0'; *fullrest_ = '\0';
-         if ( c.rest_ != NULL ) std::strcpy(rest_, c.rest_);
-         if ( c.fullrest_ != NULL ) std::strcpy(fullrest_, c.fullrest_);
+      : BaseClass(c)
+       {
+         *fullrest_ = '\0';
+         std::strcpy(fullrest_, c.fullrest_);
        }
-    Bed4(char const* chrom, CoordType start, CoordType end, char const* id, char const* rest = NULL)
-      : BaseClass(chrom, start, end, id), rest_(new char[(rest != NULL) ? (std::strlen(rest)+1) : 1]),
-            fullrest_(new char[((rest != NULL) ? (std::strlen(rest)+1) : 1) + ((id != NULL) ? (std::strlen(id)+1) : 1)]) {
-      *rest_ = '\0'; *fullrest_ = '\0';
-      if ( id && std::strcmp(id, "") != 0 )
-        std::strcpy(fullrest_, id);
-
-      if ( rest && std::strcmp(rest, "") != 0 ) {
-        if ( rest[0] != '\t' )
-          rest_[0] = '\t';
-        std::strcat(rest_, rest);
-        std::strcat(fullrest_, rest_);
-      }
-    }
-    explicit Bed4(FILE* inF) : BaseClass(), rest_(0), fullrest_(0)
+    explicit Bed4(FILE* inF) : BaseClass()
       { this->readline(inF); }
-    explicit Bed4(const std::string& inS) : BaseClass(), rest_(0), fullrest_(0)
+    explicit Bed4(const std::string& inS) : BaseClass()
       { this->readline(inS); }
 
     // Properties
-    char const* rest() const { return rest_; }
-    char const* full_rest() const { return fullrest_; }
+    inline char const* full_rest() const { return fullrest_; }
 
     // IO
     inline void print() const {
       static const std::string lclStatic = outFormatter();
       static char const* format = lclStatic.c_str();
-      std::printf(format, chrom_, start_, end_, id_, rest_);
+      std::printf(format, chrom_, start_, end_, fullrest_);
     }
     inline void println() const {
       static const std::string heapFormat = (outFormatter() + "\n");
       static char const* format = heapFormat.c_str();
-      std::printf(format, chrom_, start_, end_, id_, rest_);
+      std::printf(format, chrom_, start_, end_, fullrest_);
+    }
+    inline std::string printstr() const {
+      static const std::string tab = "\t";
+      return std::string(chrom_) + tab + std::to_string(start_) + tab + std::to_string(end_)
+               + std::string(fullrest_); // fullrest_ has whitespace out front if needed
     }
     inline int readline(const std::string& inputLine) {
-      static char chrBuf[MAXCHROMSIZE + 1];
-      chrBuf[0] = '\0';
-      static char idBuf[MAXIDSIZE + 1];
-      idBuf[0] = '\0';
-      static char restBuf[MAXRESTSIZE + 1];
-      restBuf[0] = '\0';
       static const std::string lclStatic = inFormatter();
       static char const* format = lclStatic.c_str();
+      static char other[MAXRESTSIZE+1];
+      other[0] = '\0';
+      chrom_[0] = '\0';
+      id_[0] = '\0';
+      fullrest_[0] = '\0';
       int numScanned = std::sscanf(inputLine.c_str(),
-                                   format, chrBuf,
-                                   &start_, &end_, idBuf, 
-                                   restBuf);
-      this->chrom(chrBuf);
-      this->id(idBuf);
-      if ( rest_ )
-        delete [] rest_;
-      rest_ = new char[std::strlen(restBuf) + 1];
-      std::strcpy(rest_, restBuf);
-      if ( fullrest_ )
-        delete [] fullrest_;
-      std::size_t sz = (std::strlen(restBuf)+1) + (std::strlen(idBuf) + 1);
-      fullrest_ = new char[sz];
-      std::strcpy(fullrest_, idBuf);
-      std::strcat(fullrest_, restBuf);
+                                   format, chrom_,
+                                   &start_, &end_, id_,
+                                   other);
+      const int numWritten = std::snprintf(fullrest_, MAXRESTSIZE+1, "\t%s", id_);
+      if ( other[0] != '\0' && static_cast<CoordType>(numWritten) < MAXRESTSIZE )
+        std::snprintf(fullrest_ + numWritten, MAXRESTSIZE+1-numWritten, "%s", other);
       return numScanned;
     }
     inline int readline(FILE* inputFile) {
-      static char chrBuf[MAXCHROMSIZE + 1];
-      chrBuf[0] = '\0';
-      static char idBuf[MAXIDSIZE + 1];
-      idBuf[0] = '\0';
-      static char restBuf[MAXRESTSIZE + 1];
-      restBuf[0] = '\0';
-
       static const std::string lclStatic = inFormatter();
       static char const* format = lclStatic.c_str();
+      static char other[MAXRESTSIZE+1];
+      other[0] = '\0';
+      chrom_[0] = '\0';
+      id_[0] = '\0';
+      fullrest_[0] = '\0';
       int numScanned = std::fscanf(inputFile,
-                                   format, chrBuf, 
-                                   &start_, &end_, idBuf, 
-                                   restBuf);
+                                   format, chrom_,
+                                   &start_, &end_, id_,
+                                   other);
 
       std::fgetc(inputFile); // Read and discard trailing newline
-      this->chrom(chrBuf);
-      this->id(idBuf);
-      if ( rest_ )
-        delete [] rest_;
-      rest_ = new char[std::strlen(restBuf) + 1];
-      std::strcpy(rest_, restBuf);
-      std::size_t sz = (std::strlen(restBuf)+1) + (std::strlen(idBuf) + 1);
-      if ( fullrest_ )
-        delete [] fullrest_;
-      fullrest_ = new char[sz];
-      std::strcpy(fullrest_, idBuf);
-      std::strcat(fullrest_, restBuf);
+      const int numWritten = std::snprintf(fullrest_, MAXRESTSIZE+1, "\t%s", id_);
+      if ( other[0] != '\0' && static_cast<CoordType>(numWritten) < MAXRESTSIZE )
+        std::snprintf(fullrest_ + numWritten, MAXRESTSIZE+1-numWritten, "%s", other);
       return numScanned;
     }
 
     // Operators
     Bed4& operator=(const Bed4& c) {
       BaseClass::operator=(c);
-      if ( rest_ )
-        delete [] rest_;
-      if ( fullrest_ )
-        delete [] fullrest_;
-      rest_ = new char[(c.rest_ != NULL) ? (std::strlen(c.rest_) + 1) : 1];
-      *rest_ = '\0'; if ( c.rest_ != NULL ) std::strcpy(rest_, c.rest_);
-      fullrest_ = new char[(c.fullrest_ != NULL) ? (std::strlen(c.fullrest_) + 1) : 1];
-      *fullrest_ = '\0'; if ( c.fullrest_ != NULL ) std::strcpy(fullrest_, c.fullrest_);
+      std::strcpy(fullrest_, c.fullrest_);
       return *this;
     }
 
-    ~Bed4() {
-      if ( rest_ )
-        delete [] rest_;
-      if ( fullrest_ )
-        delete [] fullrest_;
-    }
-
     static const bool UseRest = true;
 
   protected:
@@ -635,13 +510,13 @@ namespace Bed {
     using BaseClass::end_;
     using BaseClass::id_;
 
-    char* rest_;
-    char* fullrest_;
-    static std::string outFormatter() {
-      return(BaseClass::outFormatter() + "%s");
+    char fullrest_[MAXRESTSIZE + 1];
+
+    static std::string outFormatter() { /* BC::BC --> output 3 columns and fullrest_ */
+      return(BaseClass::BaseClass::outFormatter() + "%s");
     }
 
-    static std::string inFormatter() {
+    static std::string inFormatter() { /* BC --> include ID field */
       return(BaseClass::outFormatter() + "%[^\n]s\n");
     }
   };
@@ -679,35 +554,25 @@ namespace Bed {
 
     // IO
     inline int readline(const std::string& inputLine) {
-      static char chrBuf[MAXCHROMSIZE + 1];
-      chrBuf[0] = '\0';
-      static char idBuf[MAXIDSIZE + 1];
-      idBuf[0] = '\0';
       static const std::string lclStatic = inFormatter();
       static char const* format = lclStatic.c_str();
-      int numScanned = std::sscanf(inputLine.c_str(),
-                                   format, chrBuf,
-                                   &start_, &end_, idBuf, 
-                                   &measurement_);
-      this->chrom(chrBuf);
-      this->id(idBuf);
-      return numScanned;
+      *chrom_ = '\0';
+      *id_ = '\0';
+      return std::sscanf(inputLine.c_str(),
+                         format, chrom_,
+                         &start_, &end_, id_,
+                         &measurement_);
     }
     inline int readline(FILE* inputFile) {
-      static char chrBuf[MAXCHROMSIZE + 1];
-      chrBuf[0] = '\0';
-      static char idBuf[MAXIDSIZE + 1];
-      idBuf[0] = '\0';
       static const std::string lclStatic = inFormatter();
       static char const* format = lclStatic.c_str();
+      *chrom_ = '\0';
+      *id_ = '\0';
       int numScanned = std::fscanf(inputFile,
-                                   format, chrBuf, 
-                                   &start_, &end_, idBuf, 
+                                   format, chrom_,
+                                   &start_, &end_, id_,
                                    &measurement_);
-
       std::fgetc(inputFile); // Read and discard trailing newline
-      this->chrom(chrBuf);
-      this->id(idBuf);
       return numScanned;
     }
     inline void print() const {
@@ -720,6 +585,11 @@ namespace Bed {
       static char const* format = heapFormat.c_str();
       std::printf(format, chrom_, start_, end_, id_, measurement_);
     }
+    inline std::string printstr() const {
+      static const std::string tab = "\t";
+      return std::string(chrom_) + tab + std::to_string(start_) + tab + std::to_string(end_) + tab
+               + std::string(id_) + tab + std::to_string(measurement_);
+    }
 
     // Operators
     Bed5& operator=(const Bed5& c) {
@@ -737,9 +607,11 @@ namespace Bed {
     using BaseClass::id_;
     MeasureType measurement_;
 
+    typedef typename std::remove_cv<MeasureType>::type MType;
+    static constexpr char const* MFormat = Formats::Format(MType());
+
     static std::string outFormatter() {
-      typedef typename std::remove_cv<MeasureType>::type MType;
-      return(BaseClass::outFormatter() + "\t" + Formats::Format(MType()));
+      return(BaseClass::outFormatter() + "\t" + std::string(MFormat));
     }
 
     static std::string inFormatter() {
@@ -753,133 +625,92 @@ namespace Bed {
   struct Bed5
     : public Bed5<Bed4Type, MeasureType, false> { /* Bed4Type is forced to be Bed4<> specialization above */
 
-    Bed5() : BaseClass(), rest_(new char[1]) { *rest_ = '\0'; }
-    Bed5(const Bed5& c)
-      : BaseClass(c), rest_(new char[(c.rest_ != NULL) ? (std::strlen(c.rest_+1)) : 1]),
-        fullrest_(new char[(c.fullrest_ != NULL) ? (std::strlen(c.fullrest_+1)) : 1])
+    Bed5() : BaseClass() { *chrom_ = '\0'; *id_ = '\0'; *fullrest_ = '\0'; restOffset_ = -1; }
+    Bed5(const Bed5& c) : BaseClass(c), restOffset_(c.restOffset_)
       {
-        *rest_ = '\0'; if ( c.rest_ != NULL ) std::strcpy(rest_, c.rest_);
-        *fullrest_ = '\0'; if ( c.fullrest_ != NULL ) std::strcpy(fullrest_, c.fullrest_);
+        *fullrest_ = '\0'; std::strcpy(fullrest_, c.fullrest_);
       }
-    Bed5(char const* chrom, CoordType start, CoordType end,
-         char const* id, MeasureType measurement, char const* rest = NULL)
-      : BaseClass(chrom, start, end, id, measurement),
-        rest_(new char[(rest != NULL) ? (std::strlen(rest)+1) : 1]),
-        fullrest_(new char[((rest != NULL) ? (std::strlen(rest)+1) : 1) + ((id != NULL) ? (std::strlen(id)+1) : 1)])
-    {
-      *rest_ = '\0'; *fullrest_ = '\0';
-      if ( id && std::strcmp(id, "") != 0 )
-        std::strcpy(fullrest_, id);
-
-      if ( rest && 0 != std::strcmp(rest, "") ) {
-        if ( rest[0] != '\t' )
-          rest_[0] = '\t';
-        std::strcat(rest_, rest);
-        std::strcat(fullrest_, rest_);
-      }
-    }
-    explicit Bed5(FILE* inF) : BaseClass(), rest_(0), fullrest_(0)
-      { this->readline(inF); }
-    explicit Bed5(const std::string& inS) : BaseClass(), rest_(0), fullrest_(0)
-      { this->readline(inS); }
+    explicit Bed5(FILE* inF) : BaseClass()
+      { *fullrest_ = '\0'; this->readline(inF); }
+    explicit Bed5(const std::string& inS) : BaseClass()
+      { *fullrest_ = '\0'; this->readline(inS); }
 
     // Properties
-    char const* rest() const { return rest_; }
-    char const* full_rest() const { return fullrest_; }
+    inline char const* full_rest() const { return fullrest_; }
+    inline int rest_offset() const { return restOffset_; }
 
     // IO
     inline void print() const {
       static const std::string lclStatic = outFormatter();
       static char const* format = lclStatic.c_str();
-      std::printf(format, chrom_, start_, end_, id_, measurement_, rest_);
+      std::printf(format, chrom_, start_, end_, fullrest_);
     }
     inline void println() const {
       static const std::string heapFormat = outFormatter() + "\n";
       static char const* format = heapFormat.c_str();
-      std::printf(format, chrom_, start_, end_, id_, measurement_, rest_);
+      std::printf(format, chrom_, start_, end_, fullrest_);
+    }
+    inline std::string printstr() const {
+      static const std::string tab = "\t";
+      return std::string(chrom_) + tab + std::to_string(start_) + tab + std::to_string(end_)
+               + std::string(fullrest_); // fullrest_ has whitespace out front if needed
     }
     inline int readline(const std::string& inputLine) {
-      static char chrBuf[MAXCHROMSIZE + 1];
-      chrBuf[0] = '\0';
-      static char idBuf[MAXIDSIZE + 1];
-      idBuf[0] = '\0';
-      static char restBuf[MAXRESTSIZE + 1];
-      restBuf[0] = '\0';
       static const std::string lclStatic = inFormatter();
       static char const* format = lclStatic.c_str();
-      int numScanned = std::sscanf(inputLine.c_str(),
-                                   format, chrBuf,
-                                   &start_, &end_, idBuf, 
-                                   &measurement_, restBuf);
+      static char other[MAXRESTSIZE+1];
+      other[0] = '\0';
+      *chrom_ = '\0';
+      *id_ = '\0';
+      *fullrest_ = '\0';
+      restOffset_ = -1;
+      const int numScanned = std::sscanf(inputLine.c_str(),
+                                         format, chrom_,
+                                         &start_, &end_, id_,
+                                         &measurement_, other);
 
-      this->chrom(chrBuf);
-      this->id(idBuf);
-      if ( rest_ )
-        delete [] rest_;
-      rest_ = new char[std::strlen(restBuf) + 1];
-      std::strcpy(rest_, restBuf);
-      if ( fullrest_ )
-        delete [] fullrest_;
-      std::size_t sz = (std::strlen(restBuf)+1) + (std::strlen(idBuf) + 1);
-      fullrest_ = new char[sz];
-      std::strcpy(fullrest_, idBuf);
-      std::strcat(fullrest_, restBuf);
+      static const std::string fstr = std::string("\t%s\t") + BaseClass::MFormat;
+      static const char* f = fstr.c_str();
+      const int numWritten = std::snprintf(fullrest_, MAXRESTSIZE+1, f, id_, measurement_);
+      if ( other[0] != '\0' && static_cast<CoordType>(numWritten) < MAXRESTSIZE ) {
+        restOffset_ = numWritten;
+        std::snprintf(fullrest_ + numWritten, MAXRESTSIZE+1-numWritten, "%s", other);
+      }
       return numScanned;
     }
     inline int readline(FILE* inputFile) {
-      static char chrBuf[MAXCHROMSIZE + 1];
-      chrBuf[0] = '\0';
-      static char idBuf[MAXIDSIZE + 1];
-      idBuf[0] = '\0';
-      static char restBuf[MAXRESTSIZE + 1];
-      restBuf[0] = '\0';
-
       static const std::string lclStatic = inFormatter();
       static char const* format = lclStatic.c_str();
-      int numScanned = std::fscanf(inputFile,
-                                   format, chrBuf, 
-                                   &start_, &end_, idBuf, 
-                                   &measurement_, restBuf);
+      static char other[MAXRESTSIZE+1];
+      other[0] = '\0';
+      *chrom_ = '\0';
+      *id_ = '\0';
+      *fullrest_ = '\0';
+      restOffset_ = -1;
+      const int numScanned = std::fscanf(inputFile,
+                                         format, chrom_,
+                                         &start_, &end_, id_,
+                                         &measurement_, other);
 
       std::fgetc(inputFile); // Read and discard trailing newline
-      this->chrom(chrBuf);
-      this->id(idBuf);
-      if ( rest_ )
-        delete [] rest_;
-      rest_ = new char[std::strlen(restBuf) + 1];
-      std::strcpy(rest_, restBuf);
-
-      if ( fullrest_ )
-        delete [] fullrest_;
-      std::size_t sz = (std::strlen(restBuf)+1) + (std::strlen(idBuf) + 1);
-      fullrest_ = new char[sz];
-      std::strcpy(fullrest_, idBuf);
-      std::strcat(fullrest_, restBuf);
 
+      static const std::string fstr = std::string("\t%s\t") + BaseClass::MFormat;
+      static const char* f = fstr.c_str();
+      const int numWritten = std::snprintf(fullrest_, MAXRESTSIZE+1, f, id_, measurement_);
+      if ( other[0] != '\0' && static_cast<CoordType>(numWritten) < MAXRESTSIZE ) {
+        restOffset_ = numWritten;
+        std::snprintf(fullrest_ + numWritten, MAXRESTSIZE+1-numWritten, "%s", other);
+      }
       return numScanned;
     }
 
     // Operators
     Bed5& operator=(const Bed5& c) {
       BaseClass::operator=(c);
-      if ( rest_ )
-        delete [] rest_;
-      if ( fullrest_ )
-        delete [] fullrest_;
-      rest_ = new char[(c.rest_ != NULL) ? (std::strlen(c.rest_) + 1) : 1];
-      *rest_ = '\0'; if ( c.rest_ != NULL ) std::strcpy(rest_, c.rest_);
-      fullrest_ = new char[(c.fullrest_ != NULL) ? (std::strlen(c.fullrest_) + 1) : 1];
-      *fullrest_ = '\0'; if ( c.fullrest_ != NULL ) std::strcpy(fullrest_, c.fullrest_);
+      std::strcpy(fullrest_, c.fullrest_);
       return *this;
     }
 
-    ~Bed5() {
-      if ( rest_ )
-        delete [] rest_;
-      if ( fullrest_ )
-        delete [] fullrest_;
-    }
-
     // Parameters
     static const bool UseRest = true;
 
@@ -891,11 +722,11 @@ namespace Bed {
     using BaseClass::id_;
     using BaseClass::measurement_;
 
-    char* rest_;
-    char* fullrest_;
+    int  restOffset_; // marks spot after id_/measurement_ in fullrest_
+    char fullrest_[MAXRESTSIZE+1];
 
-    static std::string outFormatter() {
-      return(BaseClass::outFormatter() + "%s");
+    static std::string outFormatter() { /* BC::BC::BC --> output 3 columns and fullrest_ */
+      return BaseClass::BaseClass::BaseClass::outFormatter() + "%s";
     }
 
     static std::string inFormatter() {
@@ -905,4 +736,4 @@ namespace Bed {
 
 } // namespace Bed
 
-#endif // BED_HPP
+#endif // BED_NONEW_HPP
