@@ -8,7 +8,7 @@
 
 //
 //    BEDOPS
-//    Copyright (C) 2011-2017 Shane Neph, Scott Kuehn and Alex Reynolds
+//    Copyright (C) 2011-2018 Shane Neph, Scott Kuehn and Alex Reynolds
 //
 //    This program is free software; you can redistribute it and/or modify
 //    it under the terms of the GNU General Public License as published by
@@ -29,16 +29,18 @@
 #ifndef REVISION_HISTORY_BEDOPS_H
 #define REVISION_HISTORY_BEDOPS_H
 
+#include "suite/BEDOPS.Constants.hpp"
+
 #ifdef __cplusplus
 namespace BEDOPS {
 #endif
 
-  static const char* revision() {
-    return("2.4.26");
+  static const char* version() {
+    return "2.4.35 " BUILD_OPTS; // preprocessor string concatenation
   }
 
   static const char* citation() {
-    return("http://bioinformatics.oxfordjournals.org/content/28/14/1919.abstract");
+    return("http://bioinformatics.oxfordjournals.org/content/28/14/1919.abstract\n            https://doi.org/10.1093/bioinformatics/bts277");
   }
 
 #ifdef __cplusplus
