@@ -6,7 +6,7 @@
 
 //
 //    BEDOPS
-//    Copyright (C) 2011-2017 Shane Neph, Scott Kuehn and Alex Reynolds
+//    Copyright (C) 2011-2018 Shane Neph, Scott Kuehn and Alex Reynolds
 //
 //    This program is free software; you can redistribute it and/or modify
 //    it under the terms of the GNU General Public License as published by
@@ -285,7 +285,8 @@ STARCH_updateMetadataForChromosome(Metadata **md,
                 return STARCH_EXIT_FAILURE;
             }
             if (iter->signature) {
-                free(iter->signature), iter->signature = NULL;
+                free(iter->signature);
+                iter->signature = NULL;
             }
             if (signature) {
 #ifdef __cplusplus
@@ -365,7 +366,7 @@ STARCH_listMetadata(const Metadata *md,
             if ( (strcmp((const char *)iter->chromosome, chr) == 0) || (strcmp("all", chr) == 0) )
 #endif
                 fprintf(stdout, 
-                        "%-25s|%-65s|%-15" PRIu64 "|%-25" PRIu64 "|%-30d|%-20" PRIu64 "|%-20" PRIu64 "|%-25s|%-25s|%-25s\n", 
+                        "%-25s|%-65s|%-15" PRIu64 "|%-25" PRIu64 "|%-30lu|%-20" PRIu64 "|%-20" PRIu64 "|%-25s|%-25s|%-25s\n", 
                         iter->chromosome, 
                         iter->filename, 
                         iter->size, 
@@ -1145,7 +1146,7 @@ STARCH_readJSONMetadata(json_t **metadataJSON,
         fprintf(stderr, "\tcurrentMdOffset: %" PRIu64 "\n", static_cast<uint64_t>( currentMdOffset ));
 #else
         fprintf(stderr, "\tcurrentMdOffset: %" PRIu64 "\n", (uint64_t) currentMdOffset);
-#endif
+#endif 
 #endif
         for (mdHashIndex = 0; mdHashIndex < STARCH2_MD_FOOTER_BASE64_ENCODED_SHA1_LENGTH - 1; mdHashIndex++) {
 #ifdef __cplusplus
@@ -1911,10 +1912,14 @@ STARCH_readLegacyMetadata(const char *buf,
                                               STARCH_DEFAULT_LINE_STRING_LENGTH);
 
                 /* cleanup */
-                if (recFilename)
-                    free(recFilename), recFilename = NULL;
-                if (recChromosome)
-                    free(recChromosome), recChromosome = NULL;
+                if (recFilename) {
+                    free(recFilename);
+                    recFilename = NULL;
+                }
+                if (recChromosome) {
+                    free(recChromosome);
+                    recChromosome = NULL;
+                }
             }
             else
                 break;
